@@ -2,11 +2,13 @@
 """Caching, Highly-Available Postfix Policy Service - Greylisting"""
 
 ### requires the python-pidfile library from https://github.com/mosquito/python-pidfile
-import asyncio, pidfile, signal, functools
+import pidfile
+import asyncio
+import signal
+import functools
 from chapps.switchboard import GreylistingHandler
-from chapps.config import config
 from chapps.signals import SignalHandlerFactory
-import logging, chapps.logging
+import logging
 
 logger = logging.getLogger(__name__)
 logger.setLevel(logging.DEBUG)
@@ -16,7 +18,8 @@ def install_asyncio_signal_handlers(loop):
     for signame in {"SIGTERM", "SIGINT"}:
         sig = getattr(signal, signame)
         loop.add_signal_handler(
-            sig, functools.partial(SignalHandlerFactory.signal_handler(loop), sig)
+            sig,
+            functools.partial(SignalHandlerFactory.signal_handler(loop), sig),
         )
 
 
